@@ -1,7 +1,5 @@
 package SQL::Translator::Parser::Oracle;
 
-# -------------------------------------------------------------------
-# $Id: Oracle.pm 1440 2009-01-17 16:31:57Z jawnsy $
 # -------------------------------------------------------------------
 # Copyright (C) 2002-2009 SQLFairy Authors
 #
@@ -96,7 +94,8 @@ was altered to better handle the syntax created by DDL::Oracle.
 =cut
 
 use strict;
-use vars qw[ $DEBUG $GRAMMAR @EXPORT_OK ];
+use vars qw[ $DEBUG $VERSION $GRAMMAR @EXPORT_OK ];
+$VERSION = '1.59';
 $DEBUG   = 0 unless defined $DEBUG;
 
 use Data::Dumper;
